// Stellmotor HmIP-VDMOT (von ELV) ansteuern auf Basis eines Analogsignal, mit Signalisierung des Zustands über LED
//   verwendet als Ersatz für nicht mehr lieferbare Stellventile (TA-D12) von Veltamat
//   Die "Grundeinheit" (KR-D 12) wird nicht mehr benötigt, was den Stromverbrauch stark reduziert.
//   Der Raumtemperaturfühler (RF-D 12 ) wird weiter verwendet. 
//   Er wird mit 5V betrieben und liefert ein Signal 0...3,5V das den Sollzustand des Ventils (0V-zu .. 3,5V-auf) ausgibt
//   (Eine Kauf-Alternative wären HmIP-FALMOT-C12 bzw. HmIPW-FALMOT-C12 als Steuerung für 12 Ventile. 
//       Damit könnten aber die Raumtemperaturfühler und die vorhandene Verkabelung nicht weiter verwendet werden und es wären weitere Komponenten notwendig)
//
// Die Signalisierung des aktuellen Zustands der Stellmotoren erfolgt mit blinkenden LED. Dazu werden drei PWM-Kanäle verwendet
//
// Dieses Programm verwendet die Pico-Arduino Boarderweiterung von Earle Philhower (Version 2.6.3)
// nach Anregung des Buches "RPi Pico Schaltungen und Projekte" von Burkhard Kainka, Seite 5
// Einbindung über die Boardverwalter-URL https://github.com/earlephilhower/arduino-pico/releases/download/global/package_rp2040_index.json
// unter "Datei | Voreinstellungen" in der Arduino-IDE
//

#include <Arduino.h>
#include "pico/stdlib.h"
#include "PWM_Status.h"

#include "Stellmotor.h"

#if defined(_BOARDS_PICO_H)
//  #warning "RASPBERRY PI PICO defined"
/*
// V1 mit RJ12-Buchse für Anschluss Themperaturregler
  #define RT_Regler_A         A2                     // GPIO28 ist ADC2
  #define Feedback            A0                     // GPIO26 ist ADC0 
  #define MotorAuf_A           5
  #define MotorZu_A            6
  #define LED_Anode            0                     // Slice_Blink, Output A
  #define LED_Kathode_A        2                     // Slice_Burst, Output A
  #define slice_burst_Input_A  3                     // Slice_Burst, Input  B
*/

// V2 in Gehäuse für Hutschiene mit Ausbau für 2 Kanäle

  #define RT_Regler_A         A1                     // GPIO27 ist ADC1, GPIO28 ist ADC2
  #define Feedback            A0                     // GPIO26 ist ADC0 
  #define MotorAuf_A          21
  #define MotorZu_A           22
  #define RT_Regler_B         A2                     // GPIO27 ist ADC1, GPIO28 ist ADC2
  #define MotorAuf_B          19
  #define MotorZu_B           20
  #define LED_Anode           18                     // Slice_Blink, Output A
  #define LED_Kathode_A        6                     // Slice_Burst, Output A
  #define slice_burst_Input_A  7                     // Slice_Burst, Input  B, Muss physisch mit LED_Anode verbunden werden
  #define LED_Kathode_B       16                     // Slice_Burst, Output A
  #define slice_burst_Input_B 17                     // Slice_Burst, Input  B, Muss physisch mit LED_Anode verbunden werden
  #define ZweiKanal  


// V2 in Gehäuse für Hutschiene mit Ausbau für 2 Kanäl, Test Kanal 2 alleine
/*
  #define Feedback            A0                     // GPIO26 ist ADC0 
  #define RT_Regler_A         A2                     // GPIO27 ist ADC1, GPIO28 ist ADC2
  #define MotorAuf_A          19
  #define MotorZu_A           20
  #define LED_Anode           18                     // Slice_Blink, Output A
  #define LED_Kathode_A       16                     // Slice_Burst, Output A
  #define slice_burst_Input_A 17                     // Slice_Burst, Input  B, Muss physisch mit LED_Anode verbunden werden
//  #define ZweiKanal  
*/



#else
  #error "non supported board"
#endif


PWM_Status StatusLED_A( LED_Anode, LED_Kathode_A, slice_burst_Input_A, 10, 99);// slice_burst_Input (Input B) muss physisch mit LED-Anode verbunden werden
#if defined(ZweiKanal)
PWM_Status StatusLED_B( LED_Anode, LED_Kathode_B, slice_burst_Input_B, 10, 99);// slice_burst_Input (Input B) muss physisch mit LED-Anode verbunden werden
#endif

Stellmotor Motor_A(MotorAuf_A, MotorZu_A, RT_Regler_A, Feedback, StatusLED_A );
#if defined(ZweiKanal)
Stellmotor Motor_B(MotorAuf_B, MotorZu_B, RT_Regler_B, Feedback, StatusLED_B );
#endif

void setup() {
  set_sys_clock_48mhz();                                                // 125MHz ist Standard, dann aber Blinkfrequenz minimal 3,7Hz; mit 48MHz sind es 1,42 Hz
  
  Serial.begin(115200); 
  sleep_ms(5000);                                                      // Zeit bis Nutzer seriellen Monitor aufmacht
  Serial.println("Vor Aufruf PWM");
  StatusLED_A.init();
#if defined(ZweiKanal)
  StatusLED_B.init();
#endif
  StatusLED_A.start();
  Serial.println("Nach Aufruf PWM");

  Serial.println("Motor A:");
  Motor_A.init();                                                      // Evtl. hier ein Flag rein für Mess-Modus
#if defined(ZweiKanal)
  Serial.println("Motor B:");
  Motor_B.init();       
#endif                                               // Evtl. hier ein Flag rein für Mess-Modus
// Motor_A.init_mess();                                                  // Für Messungen alternativ
}

void loop() {
  Serial.print("Motor A:");
  Motor_A.messen();  
  delay(5000); // das später auf 10sec=10000 oder gar eine Minute = 60000 erhöhen, damit nicht zu oft verstellt wird
#if defined(ZweiKanal)
  Serial.print("Motor B:");
  Motor_B.messen();  
  delay(5000); // das später auf 10sec=10000 oder gar eine Minute = 60000 erhöhen, damit nicht zu oft verstellt wird
#endif
}

